<br>
<p align="center">
    <a href="https://biomass-core.readthedocs.io/en/latest">
        <img src="https://raw.githubusercontent.com/biomass-dev/biomass/master/docs/_static/img/biomass-logo.png" width="400">
    </a>
</p>

[![PyPI version](https://img.shields.io/pypi/v/biomass.svg?logo=PyPI&logoColor=white)](https://pypi.python.org/pypi/biomass)
[![Actions Status](https://github.com/biomass-dev/biomass/workflows/Tests/badge.svg)](https://github.com/biomass-dev/biomass/actions)
[![Documentation Status](https://img.shields.io/readthedocs/biomass-core/latest.svg?logo=read%20the%20docs&logoColor=white&&label=Docs&version=latest)](https://biomass-core.readthedocs.io/en/latest/?badge=latest)
[![License](https://img.shields.io/badge/License-Apache%202.0-green.svg?logo=apache)](https://opensource.org/licenses/Apache-2.0)
[![Downloads](https://pepy.tech/badge/biomass)](https://pepy.tech/project/biomass)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/biomass.svg?logo=Python&logoColor=white)](https://pypi.python.org/pypi/biomass)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/biomass-dev/biomass/master.svg)](https://results.pre-commit.ci/latest/github/biomass-dev/biomass/master)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)
[![Cancers Paper](https://img.shields.io/badge/DOI-10.3390%2Fcancers12102878-blue)](https://doi.org/10.3390/cancers12102878)

_BioMASS_ is a computational framework for modeling and analysis of biological signaling systems in Python.

- **Documentation:** https://biomass-core.rtfd.io
- **Source code:** https://github.com/biomass-dev/biomass
- **Bug reports:** https://github.com/biomass-dev/biomass/issues
- **Citing in your work:** https://biomass-core.rtfd.io/en/latest/citing.html

It provides useful tools for numerical simulation, parameter estimation, network analysis, and result visualization.

## Installation

The BioMASS library is available at the [Python Package Index (PyPI)](https://pypi.org/project/biomass).

```shell
$ pip install biomass
```

BioMASS supports Python 3.8 or newer.

## References

- Imoto, H., Zhang, S. & Okada, M. A Computational Framework for Prediction and Analysis of Cancer Signaling Dynamics from RNA Sequencing Data—Application to the ErbB Receptor Signaling Pathway. _Cancers_ **12**, 2878 (2020). https://doi.org/10.3390/cancers12102878

- Imoto, H., Yamashiro, S. & Okada, M. A text-based computational framework for patient -specific modeling for classification of cancers. _iScience_ **25**, 103944 (2022). https://doi.org/10.1016/j.isci.2022.103944

## Author

[Hiroaki Imoto](https://github.com/himoto)

## License

[Apache License 2.0](https://github.com/biomass-dev/biomass/blob/master/LICENSE)
